// Copyright 2020 ESRI
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
#include "Display_a_map.h"
#include "ArcGISRuntimeEnvironment.h"

#include "Basemap.h"
#include "Map.h"
#include "MapQuickView.h"


#include <QUrl>

using namespace Esri::ArcGISRuntime;

Display_a_map::Display_a_map(QObject* parent /* = nullptr */):
    QObject(parent),
    m_map(new Map(BasemapStyle::ArcGISTopographic, this))
{
}

Display_a_map::~Display_a_map()
{
}

MapQuickView* Display_a_map::mapView() const
{
    return m_mapView;
}

void Display_a_map::setupViewpoint()
{

  const QString item_id("41281c51f9de45edaf1c8ed44bb10e30");
  const QUrl portal_url(QString("https://arcgis.com/sharing/rest/content/items/" + item_id));
  m_map = new Map(portal_url, this);
  m_mapView->setMap(m_map);

}
// Set the view (created in QML)
void Display_a_map::setMapView(MapQuickView* mapView)
{
  if (!mapView || mapView == m_mapView)
  {
    return;
  }

  m_mapView = mapView;
  m_mapView->setMap(m_map);
  setupViewpoint();

  emit mapViewChanged();
}

